@@ -1,6 +1,8 @@
 # -*- coding: utf-8 -*-
 
-from qtpy import QtCore, QtGui
+from qtpy import QtGui
+
+from prettyqt import core
 
 
 class PolygonF(QtGui.QPolygonF):
@@ -8,14 +10,10 @@ class PolygonF(QtGui.QPolygonF):
         return type(self), (), self.__getstate__()
 
     def __getstate__(self):
-        ba = QtCore.QByteArray()
-        stream = QtCore.QDataStream(ba, QtCore.QIODevice.WriteOnly)
-        stream << self
-        return ba
+        return core.DataStream.create_bytearray(self)
 
     def __setstate__(self, ba):
-        stream = QtCore.QDataStream(ba, QtCore.QIODevice.ReadOnly)
-        stream >> self
+        core.DataStream.write_bytearray(ba, self)
 
     @classmethod
     def from_xy(cls, xdata, ydata):
@@ -33,6 +31,4 @@ class PolygonF(QtGui.QPolygonF):
 
 
 if __name__ == "__main__":
-    from prettyqt import core
-
     poly = PolygonF((core.Point(1, 1), core.Point(2, 2)))
