@@ -1,6 +1,4 @@
 # -*- coding: utf-8 -*-
-"""
-"""
 
 from typing import Dict, Any
 
@@ -23,9 +21,9 @@ QtWidgets.QDockWidget.__bases__ = (widgets.Widget,)
 
 
 class DockWidget(QtWidgets.QDockWidget):
-    """
-    Customized DockWidget class
-    contains a custom TitleBar with maximise button
+    """Customized DockWidget class.
+
+    Contains a custom TitleBar with maximise button
     """
 
     def __init__(self, *args, **kwargs):
@@ -38,7 +36,7 @@ class DockWidget(QtWidgets.QDockWidget):
             self.set_title(title)
         self.set_allowed_areas("all")
 
-    def __getstate__(self) -> Dict[str, Any]:
+    def serialize_fields(self) -> Dict[str, Any]:
         return dict(widget=self.widget())
 
     def __setstate__(self, state: Dict[str, Any]) -> None:
